@@ -1,5 +1,3 @@
-context("Labelled")
-
 # var_label --------------------------------------------------------------
 
 test_that("var_label works properly", {
@@ -10,6 +8,7 @@ test_that("var_label works properly", {
   var_label(x) <- NULL
   expect_null(attr(x, "label"))
   expect_null(var_label(x))
+  expect_no_error(var_label(x) <- NA_character_)
 
   x <- 1:3
   x <- set_variable_labels(x, "value")
@@ -51,15 +50,13 @@ test_that("var_label produce appropriate errors", {
       set_variable_labels(x = "ghj", z = "ggg")
   )
   # no error if .strict = FALSE
-  expect_error(
+  expect_no_error(
     df %>%
-      set_variable_labels(.labels = list(x = "xx", z = "zz"), .strict = FALSE),
-    NA
+      set_variable_labels(.labels = list(x = "xx", z = "zz"), .strict = FALSE)
   )
-  expect_error(
+  expect_no_error(
     df %>%
-      set_variable_labels(x = "ghj", z = "ggg", .strict = FALSE),
-    NA
+      set_variable_labels(x = "ghj", z = "ggg", .strict = FALSE)
   )
 })
 
@@ -86,8 +83,8 @@ test_that("x must be numeric or character", {
 
 test_that("x and labels must be compatible", {
   expect_error(labelled(1, "a"))
-  expect_error(labelled(1, c(female = 2L, male = 1L)), NA)
-  expect_error(labelled(1L, c(female = 2, male = 1)), NA)
+  expect_no_error(labelled(1, c(female = 2L, male = 1L)))
+  expect_no_error(labelled(1L, c(female = 2, male = 1)))
 })
 
 test_that("labels must have names", {
@@ -244,7 +241,7 @@ test_that(" 'val_labels <-'  works for dataframe", {
     num = c(two = 2)
   )
   vldf <- df
-  expect_error(val_labels(vldf) <- valeurs, NA)
+  expect_no_error(val_labels(vldf) <- valeurs)
 
   expect_null(val_labels(vldf)$fac)
   expect_equal(df$fac, vldf$fac)
@@ -410,7 +407,7 @@ test_that("remove_labels works with labelled_spss", {
   xhs <- haven::labelled_spss(
     c(1, 2, 3, NA, 99),
     c(t1 = 1, t2 = 2, Missing = 99),
-    na_value = 99,
+    na_values = 99,
     na_range = c(99, Inf),
     label = "A test variable"
   )
@@ -486,14 +483,15 @@ test_that("sort_val_labels works properly", {
   x <- c(2, tagged_na("z"), 1, tagged_na("a"))
   val_labels(x) <-
     c(no = 2, refused = tagged_na("z"), yes = 1, dk = tagged_na("a"))
-  expect_equivalent(
+  expect_equal(
     sort_val_labels(x, according_to = "v") %>%
       val_labels() %>%
       format_tagged_na() %>%
       trimws(),
-    c("1", "2", "NA(a)", "NA(z)")
+    c("1", "2", "NA(a)", "NA(z)"),
+    ignore_attr = "names"
   )
-  expect_equivalent(
+  expect_equal(
     sort_val_labels(x, according_to = "l") %>% val_labels() %>% names(),
     c("dk", "no", "refused", "yes")
   )
@@ -512,7 +510,7 @@ test_that("remove_user_na works properly", {
   xhs <- haven::labelled_spss(
     c(1, 2, NA, 98, 99),
     c(t1 = 1, t2 = 2, Missing = 99),
-    na_value = 99,
+    na_values = 99,
     na_range = c(99, Inf),
     label = "A test variable"
   )
@@ -586,7 +584,7 @@ test_that("to_factor boolean parameters", {
   x1 <- haven::labelled_spss(
     c(1, 2, 3, 5, 4, NA, 99),
     c(t1 = 1, t2 = 2, t5 = 5, Missing = 99),
-    na_value = 99
+    na_values = 99
   )
 
   tfx <- to_factor(x1, user_na_to_na = TRUE)
@@ -609,7 +607,7 @@ test_that("to_factor parameters : sort_levels + levels", {
   x1 <- haven::labelled_spss(
     c(1, 2, 3, 5, 4, NA, 99),
     c(t1 = 1, t2 = 2, t5 = 5, Missing = 99),
-    na_value = 99
+    na_values = 99
   )
 
   tfx <- to_factor(x1, sort_levels = "auto")
@@ -754,16 +752,15 @@ test_that("set_value_labels errors", {
       )
   )
   # no error if .strict = FALSE
-  expect_error(
+  expect_no_error(
     df %>%
       set_value_labels(
         s1 = c(Male = "M", Female = "F"),
         s3 = c(Yes = 1, No = 2),
         .strict = FALSE
-      ),
-    NA
+      )
   )
-  expect_error(
+  expect_no_error(
     df %>%
       set_value_labels(
         .labels = list(
@@ -771,8 +768,7 @@ test_that("set_value_labels errors", {
           s3 = c(Yes = 1, No = 2)
         ),
         .strict = FALSE
-      ),
-    NA
+      )
   )
 })
 
@@ -799,16 +795,15 @@ test_that("add_value_labels errors", {
       )
   )
   # no error if .strict = FALSE
-  expect_error(
+  expect_no_error(
     df %>%
       add_value_labels(
         s1 = c(Male = "M", Female = "F"),
         s3 = c(Yes = 1, No = 2),
         .strict = FALSE
-      ),
-    NA
+      )
   )
-  expect_error(
+  expect_no_error(
     df %>%
       add_value_labels(
         .labels = list(
@@ -816,8 +811,7 @@ test_that("add_value_labels errors", {
           s3 = c(Yes = 1, No = 2)
         ),
         .strict = FALSE
-      ),
-    NA
+      )
   )
 
   expect_error(add_value_labels(df, s1 = c("F", Male = "M")))
@@ -1166,12 +1160,13 @@ test_that("names_prefixed_by_values works properly", {
     c1 = c("[M] Male", "[F] Female"),
     c2 = c("[1] Yes", "[2] No")
   )
-  expect_equivalent(
+  expect_equal(
     names_prefixed_by_values(val_labels(df)),
-    res_names_prefixed
+    res_names_prefixed,
+    ignore_attr = "names"
   )
 
-  expect_true(is.null(names_prefixed_by_values(NULL)))
+  expect_null(names_prefixed_by_values(NULL))
 })
 
 test_that("null_action in var_label() works as expected", {
@@ -1200,6 +1195,26 @@ test_that("null_action in var_label() works as expected", {
       Species = "Species"
     )
   )
+  expect_equal(
+    var_label(df, null_action = "na"),
+    list(
+      Sepal.Length = NA_character_,
+      Sepal.Width = NA_character_,
+      Petal.Length = "length of petal",
+      Petal.Width = "width of petal",
+      Species = NA_character_
+    )
+  )
+  expect_equal(
+    var_label(df, null_action = "empty"),
+    list(
+      Sepal.Length = "",
+      Sepal.Width = "",
+      Petal.Length = "length of petal",
+      Petal.Width = "width of petal",
+      Species = ""
+    )
+  )
   expect_equal(
     var_label(df, null_action = "skip"),
     list(
